WriteTrustIter

Trait WriteTrustIter 

pub trait WriteTrustIter<T: Clone> {
    // Required method
    fn write<O: UninitRefMut<T>>(self, out: &mut O) -> TResult<()>;
}
Trait for types that can be written to an uninitialized vector using a trusted iterator.

Required Methods

fn write<O: UninitRefMut<T>>(self, out: &mut O) -> TResult<()>

Writes the contents of this iterator to the given uninitialized vector.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors

Source

impl<I: TrustedLen> WriteTrustIter<<I as Iterator>::Item> for I
where I::Item: Clone,